# TEXTA Elastic Tools Python Package

Texta Elasticsearch tools

##### From Git
`pip3 install git+https://git.texta.ee/texta/texta-elastic-tools-python`

##### From PyPI
`pip3 install texta-elastic-tools`

### Testing
`python3 -m pytest -v tests`
